@@ -5,21 +5,21 @@
 //! The main Ockam crate re-exports this macro.
 
 use proc_macro::TokenStream;
+
 use quote::quote;
+use syn::{parse_macro_input, DeriveInput};
 
-pub fn entry(input: TokenStream) -> TokenStream {
-    let ast = syn::parse(input).expect("failed to parse macro input");
-
-    // Build the trait implementation
-    impl_message_macro(&ast)
+pub(crate) fn entry(input: TokenStream) -> TokenStream {
+    let input = parse_macro_input!(input as DeriveInput);
+    parse(&input)
 }
 
-fn impl_message_macro(ast: &syn::DeriveInput) -> TokenStream {
-    let name = &ast.ident;
-    let generics = &ast.generics;
+fn parse(input: &DeriveInput) -> TokenStream {
+    let name = &input.ident;
+    let generics = &input.generics;
     let (impl_generics, ty_generics, where_clause) = generics.split_for_impl();
-    let gen = quote! {
+    let output = quote! {
         impl #impl_generics Message for #name #ty_generics #where_clause {}
     };
-    gen.into()
+    output.into()
 }
